@@ -1,6 +1,6 @@
 import io
 from typing import *
-from .scpi_transport_base import ScpiTransportBase
+from .scpi_transport_base import ScpiTransports
 from .scpi_type_base import ScpiTypeBase
 
 
@@ -33,16 +33,18 @@ class ScpiChars(ScpiTypeBase):
         return self._data
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]) -> 'ScpiChars':
+    def parse(cls, transport: ScpiTransports) -> 'ScpiChars':
         """Parses stream data from the device and creates a `ScpiChars` object"""
         s = transport.readline()
         return ScpiChars(s)
 
+
 class ScpiNumber(ScpiTypeBase):
     """
     Class representing IEEE488.2 flexible Decimal/Nondecimal numeric NRf program data (7.7.2/7.7.4) and
     NR1/NR2/NR3 response data (8.7.2/8.7.3/8.7.4)
     """
+
     def __init__(self, value: Union[int, float], unit: Optional[str] = None):
         """Initializes the object from either an int (NR1) or float (NR2/NR3) value with an optional unit string"""
         super().__init__()
@@ -83,18 +85,18 @@ class ScpiNumber(ScpiTypeBase):
             raise TypeError
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiNumber` object"""
         data = transport.readline()
         substrs = data.split(' ')
         try:
             # Try as NR1 representation first
             value = int(substrs[0])
-        except:
+        except ValueError:
             try:
                 # Otherwise NR2 or NR3 representation
                 value = float(substrs[0])
-            except:
+            except ValueError:
                 raise TypeError
 
         # Unit available?
@@ -105,6 +107,7 @@ class ScpiNumber(ScpiTypeBase):
 
         return ScpiNumber(value, unit)
 
+
 class ScpiString(ScpiTypeBase):
     """"
     Class representing IEEE488.2 String program data (7.7.5) and response data (8.7.8)
@@ -140,11 +143,11 @@ class ScpiString(ScpiTypeBase):
         raise NotImplementedError
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiString` object"""
         quotes = 0
         string = ""
-        while(1):
+        while 1:
             chunk = transport.readline()
             # TODO: double quotes
 
@@ -157,6 +160,7 @@ class ScpiString(ScpiTypeBase):
         string = string.strip('\r\n\t"')
         return ScpiString(string)
 
+
 class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
     """
     Class representing IEEE488.2 Arbitrary block program data (7.7.6) and
@@ -168,7 +172,7 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
     Note that this class is derived from io.RawIOBase and can be used for stream processing
     """
 
-    def __init__(self, transport: Type[ScpiTransportBase], length: int) -> None:
+    def __init__(self, transport: ScpiTransports, length: int) -> None:
         """Initialize object from a `ScpiTransportBase` object and length integer"""
         super().__init__()
         self._transport = transport
@@ -225,7 +229,7 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
         raise NotImplementedError()
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiArbStream` object"""
         head = transport.read(2)
 
@@ -243,10 +247,12 @@ class ScpiArbStream(ScpiTypeBase, io.RawIOBase):
 
         return ScpiArbStream(transport, length)
 
+
 class ScpiBool(ScpiTypeBase):
     """
     Class representing SCPI-99 boolean (Vol. 1, 7.3)
     """
+
     def __init__(self, onoff: bool) -> None:
         """Initializes the object from a Python bool type"""
         super().__init__()
@@ -273,7 +279,7 @@ class ScpiBool(ScpiTypeBase):
             return "OFF"
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiBool` object"""
         data = transport.readline()
         if int(data) == 0:
@@ -281,6 +287,7 @@ class ScpiBool(ScpiTypeBase):
         else:
             return ScpiBool(True)
 
+
 class ScpiNumList(ScpiTypeBase):
     """
     Class representing a SCPI-99 numeric list (Vol. 1, 8.8.3) using the
@@ -305,16 +312,18 @@ class ScpiNumList(ScpiTypeBase):
         return '(' + ','.join(map(str, self._numlist)) + ')'
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         """Parses stream data from the device and creates a `ScpiNumList` object"""
         data = transport.readline()
         substrs = data.strip('()').split(',')
         return ScpiNumList([int(e) for e in substrs])
 
+
 class ScpiEvent(ScpiTypeBase):
     """
     Class representing a SCPI-99 error/event queue item (Vol. 2, 21.8)
     """
+
     def __init__(self, code: int, description: str, info: Optional[str] = None) -> None:
         self._code = code
         self._description = description
@@ -343,7 +352,7 @@ class ScpiEvent(ScpiTypeBase):
         raise NotImplementedError
 
     @classmethod
-    def parse(cls, transport: Type[ScpiTransportBase]):
+    def parse(cls, transport: ScpiTransports):
         data = transport.readline()
         substrs = data.split(',')
         event = substrs[1].strip('"').split(';')
@@ -351,4 +360,3 @@ class ScpiEvent(ScpiTypeBase):
         description = event[0]
         info = event[1] if len(event) > 1 else None
         return ScpiEvent(code, description, info)
-
